# Configuring Automated Nightly Runs for Inbound Processors
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/configuring-automated-nightly-runs-for-inbound-processors#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/configuring-automated-nightly-runs-for-inbound-processors#prerequisites)
  * [Procedure](https://help.sap.com/docs/leanix/ea/configuring-automated-nightly-runs-for-inbound-processors#procedure)


Adjust the configuration of inbound Integration API processors to enable automated nightly runs.
